@@ -1,66 +1,66 @@
 # -* wish *-
 # fallback which allows me to run wordview.tcl without doing make
+package require Tcl 8.3
+
 if ![info exist charset_lib] {
   set charset_lib /usr/local/lib/catdoc
 }
-set font 8x13
-# Find options (All this can be tuned from dialog)
-set FindMode -exact ;# no -regexp for novices
-set FindDir -forwards ;# Why not -backwards
-set FindCase -nocase ;# Leave it empty if you want to be case sensitive
-foreach i {file edit search  help} {
-option add *$i.highlightBackground MidnightBlue 
-option add *$i.highlightThickness 0
-option add *$i.borderWidth 0
-}
-option add *m.activeBackground MidnightBlue 80 
-option add *m.activeForeground white 80 
-option add *m.activeBorderWidth 0 80
-menubutton .file -text File -menu .file.m -underline 0
-set m [menu .file.m]
+option add *Text.Font {Courier 11} widgetDefault
+option add *Text.Background white widgetDefault
+option add *Text.Foreground black widgetDefault
+option add *Text.selectBackground black widgetDefault
+option add *Text.selectForeground white widgetDefault
+option add *Text.findMode exact widgetDefault
+option add *Text.findCase no widgetDefault
+option add *Menu.highlightBackground MidnightBlue widgetDefault
+option add *Menu.highlightThickness 0 widgetDefault
+option add *Menu.activeBackground MidnightBlue widgetDefault
+option add *Menu.activeForeground white widgetDefault
+option add *Menu.activeBorderWidth 0 widgetDefault
+menu .mainmenu
+. configure -menu .mainmenu
+.mainmenu add cascade  -label File -menu [set m [menu .mainmenu.file]] -underline 0
 $m add command -label Open... -command load_file -accelerator Ctrl-O
 $m add command -label "Save As..." -command write_file -accelerator Ctrl-S -state disabled
 $m add separator
 $m add command -label Quit -command exit -accelerator Alt-F4
-menubutton .edit -text Edit -menu .edit.m -underline 0 -state disabled
-set m [menu .edit.m -postcommand EditEnable]
+set m [menu .mainmenu.edit -postcommand EditEnable]
+.mainmenu add cascade -label Edit -menu $m -underline 0 -state disabled
 $m add command -label Copy -command CopySel -accelerator Ctrl-C
 $m add separator
 $m add command -label "Select All" -accelerator Ctrl-A -command \
  {.text tag add sel 0.0 end}
-menubutton .search -text Find -menu .search.m -underline 1 -state disabled
-set m [menu .search.m -postcommand EnableSearch]
+.mainmenu add cascade -label Find -menu .mainmenu.search -underline 1 -state disabled
+set m [menu .mainmenu.search -postcommand EnableSearch]
 $m add command -label "Find..." -command FindDialog -accelerator Ctrl-F
 $m add command -label "Find Again" -accelerator F3 -command DoFind
 #  
 # build charset menu
 # 
-set in_list {Default unicode}
-set out_list {Default}
+
+.mainmenu add cascade -state disabled -label Encoding -menu [set m [menu .mainmenu.encoding]]
+$m add radio -label Default -value Default -var in_charset 
+$m add radio -label unicode -value unicode -var in_charset 
 foreach l [glob [file join $charset_lib *.txt]] {
     set n [file rootname [file tail $l]]
-    lappend in_list $n
-    lappend out_list $n
+    $m add radio -label $n -value $n -var in_charset
 }
 
-set in_charset Default
-set out_charset Default
-
-eval tk_optionMenu .inchar in_charset $in_list
-eval tk_optionMenu .outchar out_charset $out_list
-.inchar configure -state disabled
-.outchar configure -state disabled
-label .inlab -text "Input"
-label .outlab -text "Output"
+set in_charset Default 
 
 trace var in_charset w reread
-trace var out_charset w reread
-menubutton .help -text Help -menu .help.m -underline 0
-set m [menu .help.m]
+set m [menu .mainmenu.help]
+.mainmenu  add cascade -label Help -menu $m -underline 0
+$m add command -label "Manual page" -command [list  show_help [file tail $argv0]]
+$m add command -label "Regular expressions" -command {show_help re_syntax}
+$m add separator
 $m add command -label "About..." -command AboutDialog
-text .text -width 80 -height 25 -font $font -xscrollcommand ".xs set" \
-    -yscrollcommand ".ys set" -background white -font $font -wrap word \
-    -selectforeground white -selectbackground black -spacing3 2m 
+
+
+
+text .text -width 80 -height 25  -xscrollcommand ".xs set" \
+    -yscrollcommand ".ys set"   -wrap word \
+     -spacing3 2m 
 .text tag configure sel -relief flat -borderwidth 0
 .text tag configure doc -lmargin1 0.2i -lmargin2 0
 scrollbar .ys -orient vert -command ".text yview"
@@ -72,25 +72,46 @@ bind .text <Control-S> {write_file}
 bind .text <Control-s> {write_file}
 bind .text <Control-F> FindDialog
 bind .text <Control-f> FindDialog
-grid .file .edit .search  .inlab .inchar .outlab .outchar x .help -sticky w
-grid .text - - -  - - - - - .ys
-grid .xs - - -  - - - - - 
+grid .text .ys
+grid .xs x  
 grid .text -sticky news
 grid .xs -sticky we
 grid .ys -sticky ns
-grid columnconfigure . 0 -weight 0
+grid columnconfigure . 0 -weight 1 
 grid columnconfigure . 1 -weight 0
-grid columnconfigure . 2 -weight 0
-grid columnconfigure . 3 -weight 0 
-grid columnconfigure . 4 -weight 0
-grid columnconfigure . 5 -weight 0
-grid columnconfigure . 6 -weight 0
-grid columnconfigure . 7 -weight 1 
-grid columnconfigure . 8 -weight 0
-grid columnconfigure . 9 -weight 0
-grid rowconfigure . 0 -weight 0
-grid rowconfigure . 1 -weight 1
-grid rowconfigure . 2 -weight 0
+grid rowconfigure . 0 -weight 1 
+grid rowconfigure . 1 -weight 0
+
+# Find options (All this can be tuned from dialog)
+set FindMode -[option get .text findMode FindMode] ;# no -regexp for novices
+set FindDir -forwards ;# Why not -backwards
+set FindCase -nocase ;# Leave it empty if you want to be case sensitive
+if {[option get .text findCase FindCase]} {
+	set FindCase ""
+}	
+
+
+proc show_help {page} {
+	global argv0
+	if [winfo exists .man] {
+		wm deiconify .man
+		raise .man
+		.man.text delete 0.0 end
+	} else {	
+		toplevel .man -class Man
+		wm title .man "[file tail $argv0] help: $page"
+		menu .man.menu 
+		.man.menu add cascade -label File -menu [set m [menu .man.menu.file]]
+		.man configure -menu .man.menu
+		$m add command -label Close -command {destroy .man}
+		text .man.text -yscrollcommand {.man.y set}
+		scrollbar .man.y -command {.man.text yview} -orient vert
+		grid .man.text .man.y -sticky news
+		grid columnconfigure .man 0 -weight 1
+		grid columnconfigure .man 1 -weight 0
+	}
+	.man.text insert end [exec man $page 2>/dev/null | col -b ]
+}	
 
 proc load_file {{name {}}} {
 global filename
@@ -102,11 +123,10 @@ if ![file readable $name] {
   return -code error "Cannot open file $name"
 }
 set filename $name
-.inchar configure -state normal
-.outchar configure -state normal
-.file.m entryconfigure "Save As..." -state normal
-.edit configure -state normal
-.search configure -state normal
+.mainmenu entryconfigure Encoding -state normal
+.mainmenu.file entryconfigure "Save As..." -state normal
+.mainmenu  entryconfigure "Edit" -state normal
+.mainmenu entryconfigure "Find"  -state normal
 reread
 }
 
@@ -122,8 +142,8 @@ proc reread {args} {
 global filename in_charset out_charset
 
 set inopt [make_opt in_charset -s]
-set outopt [make_opt out_charset -d]
-set f [open "|catdoc -w $inopt $outopt \"$filename\"" r]
+set f [open "|catdoc -w $inopt -d utf-8 \"$filename\"" r]
+fconfigure $f -encoding utf-8
 .text configure -state normal
 .text delete 0.0 end
 .text insert 0.0 [read $f] doc
@@ -154,9 +174,9 @@ proc write_file {{name {}}} {
 # -postcommand for Edit menu
 proc EditEnable {} {
 if [llength [.text tag ranges sel]] {
-  .edit.m entryconfigure Copy -state normal
+  .mainmenu.edit entryconfigure Copy -state normal
 } else {
-  .edit.m entryconfigure Copy -state disabled
+  .mainmenu.edit entryconfigure Copy -state disabled
 }
 }
 proc CopySel {} {
@@ -183,9 +203,9 @@ focus .find.top.e
 proc EnableSearch {} {
 global FindPattern ReplaceString
 if ![info exists FindPattern] {
-  .search.m entryconfigure "Find Again" -state disabled
+  .mainmenu.search entryconfigure "Find Again" -state disabled
 } else {
-  .search.m entryconfigure "Find Again" -state normal
+  .mainmenu.search entryconfigure "Find Again" -state normal
 }
 }
 proc make_transient {wpath title} {
